package com.chelvc.cloud.maintain.controller;
import com.chelvc.cloud.vehicle.api.dto.OmsCartItemDTO;
import com.chelvc.cloud.vehicle.api.param.OmsCartItemModifyParam;
import com.chelvc.cloud.vehicle.api.service.OmsCartItemService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;
import java.util.List;

/**
 * 购物车接口
 *
 * @author liude
 * @Date 2023/11/19
 **/
@Validated
@RestController
@ResponseWrapping
public class CartItemController {
    @DubboReference
    private OmsCartItemService cartItemService;

    /**
     * 新增购物车商品
     *
     * @param param 新增参数
     * @return 购物车主键
     */
    @PostMapping("/cartItem")
    public Integer addCartItem(@RequestBody @Valid OmsCartItemModifyParam param) {
        return this.cartItemService.add(param);
    }

    /**
     * 获取购物车商品列表
     *
     * @return 购物车主键
     */
    @GetMapping("/listCartItem")
    public List<OmsCartItemDTO> listCartItem() {
        return this.cartItemService.listCartItem();
    }

    /**
     * 修改购物车商品的数量
     *
     * @return 购物车主键
     */
    @GetMapping("/cartItem/{id}")
    public Integer updateCartItem(@PathVariable("id") @Min
            (value = 1, message = "优惠券主键不能小于1") Long id,Integer quantity) {
        return this.cartItemService.updateQuantity(id,quantity);
    }

    /**
     * 修改购物车商品的数量
     *
     * @return 购物车主键
     */
    @GetMapping("/cartItem/deleteCartItem")
    public void deleteCartItem(@RequestParam("ids") List<Long> ids) {
         this.cartItemService.delete(ids);
    }

    /**
     * 新增购物车商品
     *
     * @param param 新增参数
     * @return 购物车主键
     */
    @PostMapping("/cartItem/updateAttr")
    public Integer updateAttr(@RequestBody @Valid OmsCartItemModifyParam param) {
        return this.cartItemService.updateAttr(param);
    }
}
