package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.api.dto.DynamicCommentDTO;
import com.chelvc.cloud.vehicle.api.param.AddDynamicCommentParam;
import com.chelvc.cloud.vehicle.api.param.QueryDynamicCommentParam;
import com.chelvc.cloud.vehicle.api.service.DynamicCommentService;
import com.chelvc.framework.base.context.SessionContextHolder;
import com.chelvc.framework.common.model.Pagination;
import lombok.RequiredArgsConstructor;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 动态评论
 *
 * @author igl
 * @date 2023-02-25
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/client/comment")
public class DynamicCommentController {

    @DubboReference
    private DynamicCommentService iDynamicCommentService;

    /**
     * 查询列表
     * @param param 查询参数
     * @param pageCode
     * @param pageSize
     * @author igl
     * @date 2023/8/9 17:25
     */
    @GetMapping("/page")
    public Pagination<DynamicCommentDTO> list(@Validated QueryDynamicCommentParam param, Integer pageCode, Integer pageSize) {
        if (pageCode == null) {
            pageCode = 1;
        }
        if (pageSize == null) {
            pageSize = 20;
        }
        return this.iDynamicCommentService.queryPageList(param, pageCode, pageSize);
    }

    /**
     * 新增
     * @param param
     * @author igl
     * @date 2023/8/9 17:25
     */
    @PostMapping("/add")
    public void add(@Validated @RequestBody AddDynamicCommentParam param) {
        this.iDynamicCommentService.insertByBo(param, SessionContextHolder.getId());
    }
}
