package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.vehicle.api.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.api.param.HotMerchantModifyParam;
import com.chelvc.cloud.vehicle.api.service.HotMerchantService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;
import javax.validation.Valid;
import javax.validation.constraints.Min;
import java.util.List;

/**
 * 热门搜索接口
 *
 * @author liude
 * @date 2023/12/20
 */
@Validated
@RestController
@ResponseWrapping
public class HotMerchantController {
    @DubboReference
    private HotMerchantService hotMerchantService;

    /**
     * 添加用户点击埋点
     *
     * @param
     */
    @GetMapping("/hotMerchant/{id}")
    public void addHotMerchant(@PathVariable("id") @Min(value = 1, message = "商品ID不能小于1") Long id) {
        this.hotMerchantService.addHotMerchant(id);
    }


    /**
     * 热门搜索商家
     *
     * @param
     */
    @PostMapping("/listHotMerchant/")
    public List<MerchantDTO> listHotMerchant() {
       return this.hotMerchantService.listHotMerchant();
    }

    /**
     * 猜你喜欢的商家
     *
     * @param
     */
    @PostMapping("/likeMerchant/")
    public List<MerchantDTO> likeMerchant() {
       return this.hotMerchantService.likeMerchant();
    }


}
