package com.chelvc.cloud.maintain.controller;

import com.chelvc.cloud.maintain.copier.MerchantCopier;
import com.chelvc.cloud.maintain.copier.ReservationCopier;
import com.chelvc.cloud.maintain.vo.ReservationVO;
import com.chelvc.cloud.vehicle.api.dto.ReservationDTO;
import com.chelvc.cloud.vehicle.api.param.ReservationModifyParam;
import com.chelvc.cloud.vehicle.api.param.ReservationQueryParam;
import com.chelvc.cloud.vehicle.api.service.ReservationService;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import org.apache.dubbo.config.annotation.DubboReference;
import org.springframework.util.CollectionUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import javax.validation.constraints.Min;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 预约接口
 *
 * @author Woody
 * @date 2023/7/17
 */
@Validated
@RestController
@ResponseWrapping
public class ReservationController {
    @DubboReference
    private ReservationService reservationService;

    /**
     * 新增预约
     *
     * @param merchantId 商家ID
     * @param param      预约参数
     */
    @PostMapping("/merchant/{merchantId}/reservation")
    public void addReservation(@PathVariable("merchantId") @Min(value = 1, message = "商家主键不能小于1") Long merchantId,
                               @RequestBody @Valid ReservationModifyParam param) {
        this.reservationService.addReservation(merchantId, param);
    }

    /**
     * 查询用户预约列表
     *
     * @param param 查询参数
     * @return 用户预约列表
     */
    @GetMapping("/reservations")
    public List<ReservationVO> listUserReservations(@Valid ReservationQueryParam param) {
        List<ReservationDTO> reservations = this.reservationService.listUserReservations(param);
        if (CollectionUtils.isEmpty(reservations)) {
            return Collections.emptyList();
        }
        return reservations
                .stream()
                .map(o -> {
                    ReservationVO reservationVO = ReservationCopier.INSTANCE.copying(o);
                    reservationVO.setSimpleMerchantVO(MerchantCopier.INSTANCE
                            .merchantDTOToSimpleMerchantVO(o.getMerchant()));
                    return reservationVO;
                }).collect(Collectors.toList());
    }

    /**
     * 取消预约
     *
     * @param id    预约主键
     */
    @PutMapping("/reservation/{id}")
    public void deleteReservation(@PathVariable("id") @Min(value = 1, message = "预约主键不能小于1") Long id) {
        this.reservationService.deleteReservation(id);
    }
}
